{
  /**
   * Creates a contact point for an alert e.g email/slack.
   *
   * @name alert_contact.new
   *
   * @param uid:  This is a unique identifier for the alert contact point. It is automatically generated by Grafana when the contact point is created.
   * @param name: This is a user-defined name for the contact point. It is used to identify the contact point within Grafana.
   * @param type: This field specifies the type of notification that will be sent, such as "email", "slack", "pagerduty", or "webhook".
   * @param settings: This field contains the specific settings for the notification type, such as the email address to send the notification to or the webhook URL to post to. In the example you provided, the email address 
   * @param disableResolveMessage: This field controls whether or not a message should be sent when an alert condition is resolved. If set to false, a message will be sent when the alert condition is resolved.
   
   * @return A json that represent alert contact point
   */
  new(
    uid,
    name,
    type,
    address,
    message=null,
    singleEmail,
    disableResolveMessage
  )::
    {
      uid: uid,
      name: name,
      type: type,
      settings: {
        addresses: address,
        [if message != null then 'message']: message,
        singleEmail: singleEmail
      },
      disableResolveMessage: disableResolveMessage
    },
}
