  {
  /**
   * Creates Alert Rule for Grafana Dashboard|Panel 
   *
   * @name alert_rule.new
   *
   * @param id: Unique identifier of Alert-Rule in numbers
   * @param uid: Unique Identifier of Alert-Rule is Unique UID in String format
   * @param orgID: organization id for Alert-Rule
   * @param folderUID: Name of Folder available on Grafana server to make it attach with Alert-Rule
   * @param ruleGroup: Name of the Group so Alert-Rule could be bundled in groups
   * @param title: Unique title of Alert-Rule
   * @param condition: Query or expression that determines whether the alert should be triggered.
   * @param data: Array of sub-queries or conditions over query like (aggr. avg. threshold. Greater|Less) over above query
   * @param updated: Reffers to the time when actually Alert-Rule was updated last time
   * @param noDataState: This field specifies the state that the alert should be in if there is no data available to evaluate the condition. In this case, the value is NoData, indicating that the alert will enter the "no data" state
   * @param execErrState: This field specifies the state that the alert should be in if there is an error while executing the condition. In this case, the value is Error, indicating that the alert will enter the "error" state.
   * @param isPaused: This field specifies whether the alert is currently paused. In this case, the value is false, indicating that the alert is not paused and can trigger if the condition is met
   * @method addAlertCondition(alert_data): Add sub conditions with refIds to the Alert-Rules
   * @return A json that represents an Alert-Rule
   */


  new(
    id,
    uid, 
    orgID,
    folderUID,
    ruleGroup,
    title,
    condition,
    data=[],
    updated,
    noDataState,
    execErrState,
    isPaused,
    dashboardUid=null,
    panelId=null,
    interval,
    annotationDesc=null,
    annotationSummary=null
  )::
    {
      id: id, 
      uid: uid,
      orgID: orgID,
      folderUID: folderUID,
      ruleGroup: ruleGroup,
      title: title,
      condition: condition,
      updated: updated,
      noDataState: noDataState,
      execErrState: execErrState,
      isPaused: isPaused,
      [if dashboardUid != null then 'dashboardUid']:dashboardUid,
      [if panelId != null then 'panelId']:panelId,
      interval: interval,
      annotations:{
      description: annotationDesc,
      summary: annotationSummary,
      [if dashboardUid != null then '__dashboardUid__']: dashboardUid,
      [if panelId != null then '__panelId__']: panelId
      },
      _data:: 0,
    addAlertCondition(alert_data):: self {
      // automatically ref id in added targets.
      local data = super._data,
      _data: data + 1,
      data+: [alert_data],
    }
         
    },

}