local grafana = import 'grafonnet/grafana.libsonnet';
local dashboard = grafana.dashboard;
local row = grafana.row;
local template = grafana.template;
local gaugePanel = grafana.gaugePanel;
local bargaugePanel = grafana.bargaugePanel;
local singlestat = grafana.singlestat;
local prometheus = grafana.prometheus;
local panel = import 'panels_common.jsonnet';
 
 grafana.dashboard.new(
     title='SQL-Server-1',
     uid='7K7omW-4z',
     editable=true,
     # Display metrics over the last 30 minutes
     time_from='now-30m',
     
 ).addPanel(
     panel.gaugePanel1
     .addTarget(
         grafana.prometheus.target(
             # Query 'mssql_total_physical_memory_kb' from datasource
             expr='mssql_total_physical_memory_kb',

             # Label query results as 'alias'
             # (corresponds to specific instances in the application cluster)
             #legendFormat='{{alias}}',
             legendFormat='Total Memory',
         )
     ),
     gridPos = { h: 8, w: 8, x: 0, y: 0 }
 ).addPanel(
     panel.gaugePanel2
     .addTarget(
         grafana.prometheus.target(
             # Query 'mssql_available_physical_memory_kb' from datasource
             expr='mssql_available_physical_memory_kb',
             # Label query results as 'alias'
             # (corresponds to specific instances in the application cluster)
             legendFormat='{{alias}}',
         )
     ),
     gridPos = { h: 8, w: 8, x: 8, y: 0 }
 ).addPanel(
     panel.gaugePanel3
     .addTarget(
         grafana.prometheus.target(
             # Query 'mssql_available_physical_memory_kb' from datasource
             expr='mssql_total_physical_memory_kb-mssql_available_physical_memory_kb',
             # Label query results as 'alias'
             # (corresponds to specific instances in the application cluster)
             legendFormat='{{alias}}',
         )
     ),
     gridPos = { h: 8, w: 8, x: 18, y: 0 }
 ).addPanel(
     grafana.barGaugePanel.new(
         title='Database connections',
         # Direct queries to the `Prometheus` data source
         datasource='Prometheus',
         thresholds={
            mode: 'absolute',
            steps: [
               { value: 0, color: 'green' },
               { value: 50, color: 'yellow' },
               { value: 100, color: 'red' },
            ],
         },
         #min=0,
         #labelY1='Consumed memory',
         #fill=0,
         #decimals=0,
         unit='number',
        
     ).addTarget(
         grafana.prometheus.target(
             # Query 'mssql_available_physical_memory_kb' from datasource
             expr='mssql_connections{}',
             # Label query results as 'alias'
             # (corresponds to specific instances in the application cluster)
             legendFormat='{{database}}',
             
         )
     ),
     gridPos = { h: 8, w: 8, x: 8, y: 10 }
 ).addPanel(
     grafana.barGaugePanel.new(
         title='mysql transactions',
         # Direct queries to the `Prometheus` data source
         datasource='Prometheus',
         thresholds={
            mode: 'absolute',
         
         },
         #min=0,
         #labelY1='Consumed memory',
         #fill=0,
         #decimals=0,
         unit='number',
         
        
     ).addTarget(
         grafana.prometheus.target(
             # Query 'mssql_available_physical_memory_kb' from datasource
             expr='mssql_transactions{}',
             # Label query results as 'alias'
             # (corresponds to specific instances in the application cluster)
             legendFormat='{{database}}',
         )
     ),
     gridPos = { h: 8, w: 8, x: 18, y: 10 }
 ).addPanel(
     grafana.graphPanel.new(
         title='Connections',
         # Direct queries to the `Prometheus` data source
         datasource='Prometheus',
         min=0,
         labelY1='',
         fill=0,
         decimals=2,
         decimalsY1=0,
         sort='decreasing',
         legend_alignAsTable=true,
         legend_values=true,
         legend_avg=true,
         legend_current=true,
         legend_max=true,
         legend_sort='current',
         legend_sortDesc=true,
     ).addTarget(
         grafana.prometheus.target(
             # Query 'server_pending_requests' from datasource
             expr='mssql_connections{}',
             # Label query results as 'alias'
             # (corresponds to specific instances in the application cluster)
             legendFormat='{{database}}',
         )
     ),
     gridPos = { h: 8, w: 8, x: 0, y: 0 }
 ).addTemplate(
  grafana.template.datasource(
    'PROMETHEUS_DS',
    'prometheus',
    'Prometheus',
    hide='label',
  )
)
 .addTemplate(
     template.new(
    'application',
    '$PROMETHEUS_DS',
    'label_values(application)',
    label='Application',
    refresh='time',
     )
    )
    .addTemplate(
  template.new(
    'instance',
    '$PROMETHEUS_DS',
    'label_values(jvm_memory_used_bytes{application="$application"}, instance)',
    label='Instance',
    refresh='time',
  )
  )