#!/bin/bash

set -e

CURRENT_DIR=$PWD
Green='\033[1;32m'
NC='\033[0m'

function build_alerts {

  ALERTS_JSONNET_PATH=alerts
  ALERTS_BUILD_PATH=build/alerts
  ALERTS_TAR_NAME=alerts

  mkdir -p ${ALERTS_BUILD_PATH}

  echo "Cleaning up previous builds"
  rm -rf ${ALERTS_BUILD_PATH}/*.json

  ALERTS_JSONNETS=$(find ALERTS_JSONNET_PATH -type f -name "*.jsonnet"  | xargs -I{} basename {}  )

  for json_file in ${ALERTS_JSONNETS[@]};
      do
        echo "$json_file"
        filename=$(basename -- "${json_file}")
        filename="${filename%.*}"
        JSONNET_PATH=../grafonnet-lib \
        jsonnet ${ALERTS_JSONNET_PATH}/${json_file} > ${ALERTS_BUILD_PATH}/${filename}.json
        echo -e "${Green}Created new json at ${ALERTS_BUILD_PATH}/${filename}.json${NC}"
      done
  #ls -larth ${ALERTS_BUILD_PATH}

  cd ${CURRENT_DIR}
  echo -e "\n${Green}Alerts build Successfully${NC}"
  echo "JSON files in ${ALERTS_BUILD_PATH}"
}


function build_dashboards {

  DASHBOARDS_JSONNET_PATH=dashboards
  DASHBOARDS_BUILD_PATH=build/dashboards
  DASHBOARDS_TAR_NAME=dashboards

  mkdir -p ${DASHBOARDS_BUILD_PATH}

  echo "Cleaning up previous builds"
  rm -rf ${DASHBOARDS_BUILD_PATH}/*.json

  DASHBOARDS_JSONNETS=$(find ${DASHBOARDS_JSONNET_PATH} -type f -name "*.jsonnet"  | xargs -I{} basename {}  )

  for json_file in ${DASHBOARDS_JSONNETS[@]};
      do
        echo "$json_file"
        filename=$(basename -- "${json_file}")
        filename="${filename%.*}"
        JSONNET_PATH=grafonnet-lib \
        jsonnet ${DASHBOARDS_JSONNET_PATH}/${json_file} > ${DASHBOARDS_BUILD_PATH}/${filename}.json
        echo -e "${Green}Created new json at ${DASHBOARDS_BUILD_PATH}/${filename}.json${NC}"
      done
  #ls -larth ${DASHBOARDS_BUILD_PATH}
  cd ${CURRENT_DIR}
  echo -e "\n${Green}Dashboards build Successfully${NC}"
  echo "JSON files in ${DASHBOARDS_BUILD_PATH}"

}

if [ $1 == "alerts" ]; then
  echo "Building only alerts"
  build_alerts
elif [ $1 == "dashboards" ]; then
  echo "Building only dashboards"
  build_dashboards
else
  echo "Building All"
  build_alerts
  build_dashboards
fi


echo -e "\n \t \t ${Green}Build Successful${NC} \n \n JSON files are available in build folder"


